==> jc-1.4.0.tar.gz: gnu/xml/transform/WithParam.h <==
// final class gnu.xml.transform.WithParam

// class file dependencies
// @dep_class 2fc5f88270da347c gnu_xml_transform_WithParam
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_WithParam_H_
#define _JC_gnu_xml_transform_WithParam_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_gnu_xml_transform_WithParam$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_WithParam$sub_refs	_jc_gnu_xml_transform_WithParam$sub_refs;
typedef struct _jc_gnu_xml_transform_WithParam$sub_nonrefs	_jc_gnu_xml_transform_WithParam$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_WithParam$refs	_jc_gnu_xml_transform_WithParam$refs;
typedef struct _jc_gnu_xml_transform_WithParam$nonrefs	_jc_gnu_xml_transform_WithParam$nonrefs;
typedef struct _jc_gnu_xml_transform_WithParam$object	_jc_gnu_xml_transform_WithParam$object;

typedef const struct _jc_gnu_xml_transform_WithParam$vmethods	_jc_gnu_xml_transform_WithParam$vmethods;
typedef const struct _jc_gnu_xml_transform_WithParam$vtable	_jc_gnu_xml_transform_WithParam$vtable;
typedef const struct _jc_gnu_xml_transform_WithParam$vtype	_jc_gnu_xml_transform_WithParam$vtype;

// Constructors
extern void _jc_gnu_xml_transform_WithParam$method$_init$2dd70f4671f9c055(_jc_env *, struct _jc_gnu_xml_transform_WithParam$object *, struct _jc_java_lang_String$object *, struct _jc_gnu_xml_transform_TemplateNode$object *);
extern void _jc_gnu_xml_transform_WithParam$method$_init$5a0d2c7d0cf3bc7e(_jc_env *, struct _jc_gnu_xml_transform_WithParam$object *, struct _jc_java_lang_String$object *, struct _jc_gnu_xml_xpath_Expr$object *);

// Virtual methods
extern struct _jc_gnu_xml_transform_WithParam$object *_jc_gnu_xml_transform_WithParam$method$clone$0d85658151d00043(_jc_env *, struct _jc_gnu_xml_transform_WithParam$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_WithParam$method$getValue$3b376e80400ab75e(_jc_env *, struct _jc_gnu_xml_transform_WithParam$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_WithParam$method_info$clone$0d85658151d00043;
extern _jc_method _jc_gnu_xml_transform_WithParam$method_info$getValue$3b376e80400ab75e;

// Virtual methods structure
struct _jc_gnu_xml_transform_WithParam$vmethods {
	struct _jc_gnu_xml_transform_WithParam$object	*(*clone$0d85658151d00043)(_jc_env *, struct _jc_gnu_xml_transform_WithParam$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
	struct _jc_java_lang_Object$object	*(*getValue$3b376e80400ab75e)(_jc_env *, struct _jc_gnu_xml_transform_WithParam$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint);
};

// Vtable
struct _jc_gnu_xml_transform_WithParam$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_WithParam$vmethods	gnu_xml_transform_WithParam;
};

// Vtype
struct _jc_gnu_xml_transform_WithParam$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_WithParam$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_WithParam$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_gnu_xml_xpath_Expr$object	*select;
	struct _jc_gnu_xml_transform_TemplateNode$object	*content;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_WithParam$refs {
    _jc_gnu_xml_transform_WithParam$sub_refs	gnu_xml_transform_WithParam;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_WithParam$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_WithParam$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_WithParam$sub_nonrefs	gnu_xml_transform_WithParam;
};

// Object instance structure
struct _jc_gnu_xml_transform_WithParam$object {
	_jc_gnu_xml_transform_WithParam$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_WithParam$vtype	*vtype;
	_jc_gnu_xml_transform_WithParam$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_WithParam$vtype _jc_gnu_xml_transform_WithParam$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_WithParam, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_WithParam$class_object;

#endif	/* _JC_gnu_xml_transform_WithParam_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/WithParam.h <==
// final class gnu.xml.transform.WithParam

// class file dependencies
// @dep_class 2fc5f88270da347c gnu_xml_transform_WithParam
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_WithParam_H_
#define _JC_gnu_xml_transform_WithParam_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_gnu_xml_transform_WithParam$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_WithParam$sub_refs	_jc_gnu_xml_transform_WithParam$sub_refs;
typedef struct _jc_gnu_xml_transform_WithParam$sub_nonrefs	_jc_gnu_xml_transform_WithParam$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_WithParam$refs	_jc_gnu_xml_transform_WithParam$refs;
typedef struct _jc_gnu_xml_transform_WithParam$nonrefs	_jc_gnu_xml_transform_WithParam$nonrefs;
typedef struct _jc_gnu_xml_transform_WithParam$object	_jc_gnu_xml_transform_WithParam$object;

typedef const struct _jc_gnu_xml_transform_WithParam$vmethods	_jc_gnu_xml_transform_WithParam$vmethods;
typedef const struct _jc_gnu_xml_transform_WithParam$vtable	_jc_gnu_xml_transform_WithParam$vtable;
typedef const struct _jc_gnu_xml_transform_WithParam$vtype	_jc_gnu_xml_transform_WithParam$vtype;

// Constructors
extern void _jc_gnu_xml_transform_WithParam$method$_init$2dd70f4671f9c055(_jc_env *, struct _jc_gnu_xml_transform_WithParam$object *, struct _jc_java_lang_String$object *, struct _jc_gnu_xml_transform_TemplateNode$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_WithParam$method$_init$5a0d2c7d0cf3bc7e(_jc_env *, struct _jc_gnu_xml_transform_WithParam$object *, struct _jc_java_lang_String$object *, struct _jc_gnu_xml_xpath_Expr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_transform_WithParam$object *_jc_gnu_xml_transform_WithParam$method$clone$0d85658151d00043(_jc_env *, struct _jc_gnu_xml_transform_WithParam$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_WithParam$method$getValue$3b376e80400ab75e(_jc_env *, struct _jc_gnu_xml_transform_WithParam$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_WithParam$method_info$clone$0d85658151d00043;
extern _jc_method _jc_gnu_xml_transform_WithParam$method_info$getValue$3b376e80400ab75e;

// Virtual methods structure
struct _jc_gnu_xml_transform_WithParam$vmethods {
	struct _jc_gnu_xml_transform_WithParam$object	*(*clone$0d85658151d00043)(_jc_env *, struct _jc_gnu_xml_transform_WithParam$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getValue$3b376e80400ab75e)(_jc_env *, struct _jc_gnu_xml_transform_WithParam$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_WithParam$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_WithParam$vmethods	gnu_xml_transform_WithParam;
};

// Vtype
struct _jc_gnu_xml_transform_WithParam$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_WithParam$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_WithParam$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_gnu_xml_xpath_Expr$object	*select;
	struct _jc_gnu_xml_transform_TemplateNode$object	*content;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_WithParam$refs {
    _jc_gnu_xml_transform_WithParam$sub_refs	gnu_xml_transform_WithParam;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_WithParam$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_WithParam$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_WithParam$sub_nonrefs	gnu_xml_transform_WithParam;
};

// Object instance structure
struct _jc_gnu_xml_transform_WithParam$object {
	_jc_gnu_xml_transform_WithParam$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_WithParam$vtype	*vtype;
	_jc_gnu_xml_transform_WithParam$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_WithParam$vtype _jc_gnu_xml_transform_WithParam$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_WithParam, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_WithParam$class_object;

#endif	/* _JC_gnu_xml_transform_WithParam_H_ */
